/**********************************************************************************************
    Copyright (C) 2018 Oliver Eichler <oliver.eichler@gmx.de>

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.

**********************************************************************************************/

#ifndef CSCREENSHOTDIALOG_H
#define CSCREENSHOTDIALOG_H

#include "ui_IScreenshotDialog.h"

class CCanvas;
class CGisItemTrk;

class CScreenshotDialog : public QDialog, private Ui::IScreenshotDialog {
  Q_OBJECT
 public:
  CScreenshotDialog(CCanvas& canvas, QWidget* parent);
  virtual ~CScreenshotDialog() = default;

 private slots:
  void slotSave();
  void slotPrint();

 private:
  QPixmap getScreenshot(CGisItemTrk* trk);
  CGisItemTrk* getTrackForProfile();

  CCanvas& canvas;

  static constexpr int heightProfile = 400;
};

#endif  // CSCREENSHOTDIALOG_H
